==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.equipmentconfiguration_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.equipmentconfiguration_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ConfigurationDetails }
     * 
     */
    public ConfigurationDetails createConfigurationDetails() {
        return new ConfigurationDetails();
    }

    /**
     * Create an instance of {@link EquipmentConfiguration }
     * 
     */
    public EquipmentConfiguration createEquipmentConfiguration() {
        return new EquipmentConfiguration();
    }

    /**
     * Create an instance of {@link ConfigurationDetails.DORMANT }
     * 
     */
    public ConfigurationDetails.DORMANT createConfigurationDetailsDORMANT() {
        return new ConfigurationDetails.DORMANT();
    }

    /**
     * Create an instance of {@link EquipmentGenerationDetails }
     * 
     */
    public EquipmentGenerationDetails createEquipmentGenerationDetails() {
        return new EquipmentGenerationDetails();
    }

    /**
     * Create an instance of {@link TrackingDetails }
     * 
     */
    public TrackingDetails createTrackingDetails() {
        return new TrackingDetails();
    }

    /**
     * Create an instance of {@link AlternateKeys }
     * 
     */
    public AlternateKeys createAlternateKeys() {
        return new AlternateKeys();
    }

    /**
     * Create an instance of {@link ContractAndRentalDetails }
     * 
     */
    public ContractAndRentalDetails createContractAndRentalDetails() {
        return new ContractAndRentalDetails();
    }

    /**
     * Create an instance of {@link CallCenterDetails }
     * 
     */
    public CallCenterDetails createCallCenterDetails() {
        return new CallCenterDetails();
    }

    /**
     * Create an instance of {@link FacilityDetails }
     * 
     */
    public FacilityDetails createFacilityDetails() {
        return new FacilityDetails();
    }

    /**
     * Create an instance of {@link EnergyPerformance }
     * 
     */
    public EnergyPerformance createEnergyPerformance() {
        return new EnergyPerformance();
    }

    /**
     * Create an instance of {@link RevisionDetails }
     * 
     */
    public RevisionDetails createRevisionDetails() {
        return new RevisionDetails();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.equipmentconfiguration_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.equipmentconfiguration_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ConfigurationDetails }
     * 
     * @return
     *     the new instance of {@link ConfigurationDetails }
     */
    public ConfigurationDetails createConfigurationDetails() {
        return new ConfigurationDetails();
    }

    /**
     * Create an instance of {@link EquipmentConfiguration }
     * 
     * @return
     *     the new instance of {@link EquipmentConfiguration }
     */
    public EquipmentConfiguration createEquipmentConfiguration() {
        return new EquipmentConfiguration();
    }

    /**
     * Create an instance of {@link ConfigurationDetails.DORMANT }
     * 
     * @return
     *     the new instance of {@link ConfigurationDetails.DORMANT }
     */
    public ConfigurationDetails.DORMANT createConfigurationDetailsDORMANT() {
        return new ConfigurationDetails.DORMANT();
    }

    /**
     * Create an instance of {@link EquipmentGenerationDetails }
     * 
     * @return
     *     the new instance of {@link EquipmentGenerationDetails }
     */
    public EquipmentGenerationDetails createEquipmentGenerationDetails() {
        return new EquipmentGenerationDetails();
    }

    /**
     * Create an instance of {@link TrackingDetails }
     * 
     * @return
     *     the new instance of {@link TrackingDetails }
     */
    public TrackingDetails createTrackingDetails() {
        return new TrackingDetails();
    }

    /**
     * Create an instance of {@link AlternateKeys }
     * 
     * @return
     *     the new instance of {@link AlternateKeys }
     */
    public AlternateKeys createAlternateKeys() {
        return new AlternateKeys();
    }

    /**
     * Create an instance of {@link ContractAndRentalDetails }
     * 
     * @return
     *     the new instance of {@link ContractAndRentalDetails }
     */
    public ContractAndRentalDetails createContractAndRentalDetails() {
        return new ContractAndRentalDetails();
    }

    /**
     * Create an instance of {@link CallCenterDetails }
     * 
     * @return
     *     the new instance of {@link CallCenterDetails }
     */
    public CallCenterDetails createCallCenterDetails() {
        return new CallCenterDetails();
    }

    /**
     * Create an instance of {@link FacilityDetails }
     * 
     * @return
     *     the new instance of {@link FacilityDetails }
     */
    public FacilityDetails createFacilityDetails() {
        return new FacilityDetails();
    }

    /**
     * Create an instance of {@link EnergyPerformance }
     * 
     * @return
     *     the new instance of {@link EnergyPerformance }
     */
    public EnergyPerformance createEnergyPerformance() {
        return new EnergyPerformance();
    }

    /**
     * Create an instance of {@link RevisionDetails }
     * 
     * @return
     *     the new instance of {@link RevisionDetails }
     */
    public RevisionDetails createRevisionDetails() {
        return new RevisionDetails();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     * @return
     *     the new instance of {@link UserDefinedFields }
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

}
